@@ -46,6 +46,13 @@ impl<A: Actor> Parcel<A> {
             envelope: Envelope::instant(input),
         }
     }
+
+    pub(crate) fn from_envelope(envelope: Envelope<A>) -> Self {
+        Self {
+            operation: Operation::Forward,
+            envelope,
+        }
+    }
 }
 
 pub(crate) struct Envelope<A: Actor> {
@@ -67,6 +74,12 @@ impl<A: Actor> Envelope<A> {
         self.handler.handle(actor, ctx).await
     }
 
+    pub(crate) fn from_handler(handler: impl Handler<A>) -> Self {
+        Self {
+            handler: Box::new(handler),
+        }
+    }
+
     // TODO: Is it posiible to use `handle` method directly and drop this one?
     /// Creates an `Envelope` for `Action`.
     pub(crate) fn new<I>(input: I) -> Self
@@ -113,10 +126,32 @@ pub(crate) enum Operation {
     },
 }
 
+/// The priority of the sendig event.
+#[derive(Debug, Clone, Copy)]
+pub enum Priority {
+    /// Normal priority queue
+    Normal,
+    /// High priority queue
+    Instant,
+}
+
+impl Default for Priority {
+    fn default() -> Self {
+        Self::Normal
+    }
+}
+
 /// Internal `Handler` type that used by `Actor`'s routine to execute
 /// `ActionHandler` or `InteractionHandler`.
+///
+/// It has `'static` lifetime, because every handler is boxed when sent to an `Actor`.
 #[async_trait]
-trait Handler<A: Actor>: Send {
+pub trait Handler<A: Actor>: Send + 'static {
+    /// Returns priority of a handler.
+    fn priority(&self) -> Priority {
+        Priority::Normal
+    }
+
     /// Main method that expects a mutable reference to `Actor` that
     /// will be used by implementations to handle messages.
     async fn handle(&mut self, actor: &mut A, _ctx: &mut Context<A>) -> Result<(), Error>;
@@ -143,6 +178,10 @@ where
     A: ActionHandler<I>,
     I: Action,
 {
+    fn priority(&self) -> Priority {
+        Priority::Normal
+    }
+
     async fn handle(&mut self, actor: &mut A, ctx: &mut Context<A>) -> Result<(), Error> {
         let input = self.input.take().expect("action handler called twice");
         actor.handle(input, ctx).await
@@ -169,6 +208,10 @@ where
     A: InstantActionHandler<I>,
     I: InstantAction,
 {
+    fn priority(&self) -> Priority {
+        Priority::Instant
+    }
+
     async fn handle(&mut self, actor: &mut A, ctx: &mut Context<A>) -> Result<(), Error> {
         let input = self
             .input
