@@ -7,8 +7,12 @@ pub use crate::handlers::{
     InterruptedBy, Parcel, Scheduled, StartedBy, StreamAcceptor, TaskEliminated,
 };
 pub use crate::ids::{Id, IdOf};
-pub use crate::linkage::{ActionRecipient, Address, Distributor, InteractionRecipient};
-pub use crate::lite_runtime::{LiteTask, StopReceiver, StopSignal, Tag, TaskAddress, TaskError};
+pub use crate::linkage::{
+    ActionRecipient, Address, Distributor, InteractionRecipient, TaskDistributor,
+};
+pub use crate::lite_runtime::{
+    LiteTask, StopReceiver, StopSender, StopSignal, Tag, TaskAddress, TaskError,
+};
 #[cfg(not(feature = "wasm"))]
 pub use crate::signal;
 pub use crate::system::System;
